summaryrefslogtreecommitdiffstats
path: root/wgpu/src/primitive.rs
diff options
context:
space:
mode:
Diffstat (limited to 'wgpu/src/primitive.rs')
-rw-r--r--wgpu/src/primitive.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/wgpu/src/primitive.rs b/wgpu/src/primitive.rs
index 9efd74f6..04264e5d 100644
--- a/wgpu/src/primitive.rs
+++ b/wgpu/src/primitive.rs
@@ -1,5 +1,5 @@
use iced_native::{
- Background, Color, Font, HorizontalAlignment, Rectangle, Vector,
+ image, Background, Color, Font, HorizontalAlignment, Rectangle, Vector,
VerticalAlignment,
};
@@ -41,8 +41,8 @@ pub enum Primitive {
},
/// An image primitive
Image {
- /// The path of the image
- path: String,
+ /// The handle of the image
+ handle: image::Handle,
/// The bounds of the image
bounds: Rectangle,
},